export P=spatialite
export V=4.3.0a
export B=6
export MAINTAINER=JuergenFischer

savelog() {
	local f=$1
	rm -f $f.9
	for i in $(seq 8 -1 0); do [ -f "$f.$i" ] && mv $f.$i $f.$(( i + 1 )); done
	[ -f $f ] && mv $f $f.0
}

savelog package.log
exec > >(tee package.log) 2>&1
date

set -e

[ -f lib$P-$V.tar.gz ] || wget http://www.gaia-gis.it/gaia-sins/libspatialite-sources/lib$P-$V.tar.gz
if ! [ -f ../makefile.vc ]; then
	tar -C .. -xzf lib$P-$V.tar.gz --xform s,lib$P-$V,.,
	patch -d .. -p0 <diff
	cp ../config-msvc.h ../src/geopackage/config.h
	touch unistd.h
fi

if ! [ -d "$OSGEO4W_REP" ]; then
        echo no repository
        exit 1
fi

fetchenv() {
        local IFS
        IFS=
        batch=$1
        shift

        if ! [ -f "$batch" ]; then
                echo "$batch not found"
                return 1
        fi

        srcenv=$(mktemp /tmp/srcenv.XXXXXXXXXX)
        dstenv=$(mktemp /tmp/dstenv.XXXXXXXXXX)
        diffenv=$(mktemp /tmp/diffenv.XXXXXXXXXX)
        envdiff=$(mktemp /tmp/envdiff.XXXXXXXXXX)
        cmd /c set >$srcenv
        cmd /c call $(cygpath -w $batch) "$@" \>nul 2\>nul \& set >$dstenv
        /usr/bin/cat <<EOF >$envdiff
/^+++/d;
/^[^+]/d;
s/^+//;
# s/\\\\/\\\\\\\\/g;
/^PATH=/ {
        s/\\\\/\\//g;
        s#\\([=;]\\)\\([a-zA-Z]\\):#\\1/cygdrive/\\2#g;
        s/;/:/g;
}
s/;/\\\\;/g;
s/^/export /;
s/=/='/;
s/\\\\r//g;
s/\r$/'/;
EOF
        /usr/bin/diff -u $srcenv $dstenv | /usr/bin/sed -f $envdiff >$diffenv
        . $diffenv
        PATH=$PATH:/bin:/usr/bin:/cygdrive/c/windows32/system32:/cygdrive/c/windows
        rm -f $srcenv $dstenv $diffenv $envdiff
}

for ARCH in x86 x86_64; do
	export ARCH

	(
		case "$ARCH" in
		x86)
       		export OSGEO4W_ROOT=/c/OSGeo4W
       		export MACHINE=x86
			export TARGET_CPU=win32
			;;

		x86_64)
			export OSGEO4W_ROOT=/c/OSGeo4W64
        	export MACHINE=x64
			export TARGET_CPU=win64
			;;

		*)
        		echo invalid arch
        		exit 1
			;;

		esac

		export R=$OSGEO4W_REP/$ARCH/release/$P
		mkdir -p $R

		cat <<EOF >$R/setup.hint
sdesc: "The SpatiaLite library for adding spatial capabilities to SQLite3 DBMS."
ldesc: "The SpatiaLite library for adding spatial capabilities to SQLite3 DBMS."
category: Libs
requires: sqlite3 iconv geos proj freexl libxml2 liblwgeom msvc2015
maintainer: $MAINTAINER
EOF
		cp ../COPYING $R/$P-$V-$B.txt

		fetchenv $OSGEO4W_ROOT/bin/o4w_env.bat
		fetchenv "/c/Program Files (x86)/Microsoft Visual Studio 14.0/VC/vcvarsall.bat" $MACHINE

		export INSTDIR=install-$ARCH

		cd ..
		nmake /f makefile.vc clean
		nmake /f makefile.vc TARGET_CPU=$TARGET_CPU
		nmake /f makefile.vc INSTDIR=$(cygpath -a -w $INSTDIR) install

		/bin/tar -C $INSTDIR -cjf $R/$P-$V-$B.tar.bz2 bin include lib
		/bin/tar -cjf $R/$P-$V-$B-src.tar.bz2 osgeo4w/package.sh osgeo4w/diff
	)
done
